package com.junmp.jyzb.cache;

import com.junmp.jyzb.api.constant.JYZBConstant;
import com.junmp.jyzb.entity.Temp.HumidityAndtemperature;
import com.junmp.v2.cache.AbstractRedisCache;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;


@Component
public class TemperatureRedisCache extends AbstractRedisCache<HumidityAndtemperature> {
    public TemperatureRedisCache(RedisTemplate<String, HumidityAndtemperature> redisTemplate) {
        super(redisTemplate);
    }

    @Override
    public String getCommonKeyPrefix() {
        return JYZBConstant.JYZB_TEMP_PREFIX;
    }

    public void addTemperatureHumidity(String warehouseId,String warehouseName,long timestamp, double humidity, double temperature) {
        HumidityAndtemperature data = new HumidityAndtemperature();
        data.setHumidity(humidity);
        data.setTemperature(temperature);
        data.setCreateTime(timestamp);
        data.setWarehouseId(warehouseId);
        data.setWarehouseName(warehouseName);
        String key = warehouseId + ":" + timestamp;
        put(key, data);
    }
    public List<HumidityAndtemperature> getDataByTimestampRange(String warehouseId, long startTimestamp, long endTimestamp) {
        String keyPattern = warehouseId + ":*";
        Set<String> keys = getRedisTemplate().keys(keyPattern);

        List<String> keysInRange = keys.stream()
                .filter(key -> {
                    long timestamp = Long.parseLong(key.split(":")[1]);
                    return timestamp >= startTimestamp && timestamp <= endTimestamp;
                })
                .collect(Collectors.toList());

        List<HumidityAndtemperature> result = new ArrayList<>();
        for (String key : keysInRange) {
            result.add(get(key));
        }

        return result;
    }
}
